========
Ecosound
========


.. image:: https://img.shields.io/pypi/v/ecosound.svg
        :target: https://pypi.python.org/pypi/ecosound

.. image:: https://img.shields.io/travis/xaviermouy/ecosound.svg
        :target: https://travis-ci.com/xaviermouy/ecosound

.. image:: https://readthedocs.org/projects/ecosound/badge/?version=latest
        :target: https://ecosound.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/xaviermouy/ecosound/shield.svg
     :target: https://pyup.io/repos/github/xaviermouy/ecosound/
     :alt: Updates



Python library to analyse passive acoustic data


* Free software: BSD license
* Documentation: https://ecosound.readthedocs.io.


Features
--------

* TODO

Credits
-------

